=======================
The MythX Domain Models
=======================


.. image:: https://img.shields.io/pypi/v/mythx-models.svg
        :target: https://pypi.org/project/mythx-models/

.. image:: https://travis-ci.org/dmuhs/mythx-models.svg?branch=master
        :target: https://travis-ci.org/dmuhs/mythx-models

.. image:: https://readthedocs.org/projects/mythx-models/badge/?version=latest
        :target: https://mythx-models.readthedocs.io/en/latest/?badge=latest

.. image:: https://pyup.io/repos/github/dmuhs/mythx-models/shield.svg
        :target: https://pyup.io/repos/github/dmuhs/mythx-models/

.. image:: https://coveralls.io/repos/github/dmuhs/mythx-models/badge.svg?branch=master
        :target: https://coveralls.io/github/dmuhs/mythx-models?branch=master


This repository contains the domain models for the MythX_ smart contract security analysis platform.

.. contents:: Table of Contents


What is MythX?
--------------
MythX is a security analysis API that allows anyone to create purpose-built
security tools for smart contract developers. Tools built on MythX integrate
seamlessly into the development environments and continuous integration
pipelines used throughout the Ethereum ecosystem.


Installation
------------
The MythX domain models runs on Python 3.5+.

To get started, simply run

.. code-block:: console

    $ pip3 install mythx-models

Alternatively, clone the repository and run

.. code-block:: console

    $ pip3 install .

Or directly through Python's :code:`setuptools`:

.. code-block:: console

    $ python3 setup.py install


.. _MythX: https://mythx.io/
